summaryrefslogtreecommitdiffstats
path: root/sbin/fsck_ffs
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
committertrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
commit896f3841bf047ca93766900f8cd8c5852e6a9245 (patch)
tree0adfec655f17ae1258112946fa8d7d72c9c75f76 /sbin/fsck_ffs
parent0c40c9d08e198e96b30b9b27d5caea7fce0f7118 (diff)
downloadFreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.zip
FreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.tar.gz
more file system > filesystem
Diffstat (limited to 'sbin/fsck_ffs')
-rw-r--r--sbin/fsck_ffs/SMM.doc/0.t22
-rw-r--r--sbin/fsck_ffs/SMM.doc/1.t12
-rw-r--r--sbin/fsck_ffs/SMM.doc/2.t76
-rw-r--r--sbin/fsck_ffs/SMM.doc/3.t58
-rw-r--r--sbin/fsck_ffs/SMM.doc/4.t186
-rw-r--r--sbin/fsck_ffs/fsck.h16
-rw-r--r--sbin/fsck_ffs/main.c2
-rw-r--r--sbin/fsck_ffs/pass1.c2
8 files changed, 187 insertions, 187 deletions
diff --git a/sbin/fsck_ffs/SMM.doc/0.t b/sbin/fsck_ffs/SMM.doc/0.t
index 1fb25ee6..80d19f3 100644
--- a/sbin/fsck_ffs/SMM.doc/0.t
+++ b/sbin/fsck_ffs/SMM.doc/0.t
@@ -63,31 +63,31 @@ Contract No. N00039-82-C-0235.
.FE
This document reflects the use of
.I fsck_ffs
-with the 4.2BSD and 4.3BSD file system organization. This
+with the 4.2BSD and 4.3BSD filesystem organization. This
is a revision of the
original paper written by
T. J. Kowalski.
.PP
File System Check Program (\fIfsck_ffs\fR)
-is an interactive file system check and repair program.
+is an interactive filesystem check and repair program.
.I Fsck_ffs
uses the redundant structural information in the
-UNIX file system to perform several consistency checks.
+UNIX filesystem to perform several consistency checks.
If an inconsistency is detected, it is reported
to the operator, who may elect to fix or ignore
each inconsistency.
These inconsistencies result from the permanent interruption
-of the file system updates, which are performed every
+of the filesystem updates, which are performed every
time a file is modified.
Unless there has been a hardware failure,
.I fsck_ffs
-is able to repair corrupted file systems
+is able to repair corrupted filesystems
using procedures based upon the order in which UNIX honors
-these file system update requests.
+these filesystem update requests.
.PP
The purpose of this document is to describe the normal updating
-of the file system,
-to discuss the possible causes of file system corruption,
+of the filesystem,
+to discuss the possible causes of filesystem corruption,
and to present the corrective actions implemented
by
.I fsck_ffs.
@@ -108,16 +108,16 @@ Revised October 7, 1996
.LP
.sp .5v
.nf
-.B "2. Overview of the file system
+.B "2. Overview of the filesystem
2.1. Superblock
2.2. Summary Information
2.3. Cylinder groups
2.4. Fragments
-2.5. Updates to the file system
+2.5. Updates to the filesystem
.LP
.sp .5v
.nf
-.B "3. Fixing corrupted file systems
+.B "3. Fixing corrupted filesystems
3.1. Detecting and correcting corruption
3.2. Super block checking
3.3. Free block checking
diff --git a/sbin/fsck_ffs/SMM.doc/1.t b/sbin/fsck_ffs/SMM.doc/1.t
index 1930102..ea07f07 100644
--- a/sbin/fsck_ffs/SMM.doc/1.t
+++ b/sbin/fsck_ffs/SMM.doc/1.t
@@ -38,14 +38,14 @@ Introduction
.PP
This document reflects the use of
.I fsck_ffs
-with the 4.2BSD and 4.3BSD file system organization. This
+with the 4.2BSD and 4.3BSD filesystem organization. This
is a revision of the
original paper written by
T. J. Kowalski.
.PP
When a UNIX
operating system is brought up, a consistency
-check of the file systems should always be performed.
+check of the filesystems should always be performed.
This precautionary measure helps to insure
a reliable environment for file storage on disk.
If an inconsistency is discovered,
@@ -55,7 +55,7 @@ runs in two modes.
Normally it is run non-interactively by the system after
a normal boot.
When running in this mode,
-it will only make changes to the file system that are known
+it will only make changes to the filesystem that are known
to always be correct.
If an unexpected inconsistency is found
.I fsck_ffs
@@ -71,10 +71,10 @@ should be made.
.PP
The purpose of this memo is to dispel the
mystique surrounding
-file system inconsistencies.
-It first describes the updating of the file system
+filesystem inconsistencies.
+It first describes the updating of the filesystem
(the calm before the storm) and
-then describes file system corruption (the storm).
+then describes filesystem corruption (the storm).
Finally,
the set of deterministic corrective actions
used by
diff --git a/sbin/fsck_ffs/SMM.doc/2.t b/sbin/fsck_ffs/SMM.doc/2.t
index c6a8e4b..0f0bef7 100644
--- a/sbin/fsck_ffs/SMM.doc/2.t
+++ b/sbin/fsck_ffs/SMM.doc/2.t
@@ -32,22 +32,22 @@
.\" $FreeBSD$
.\" @(#)2.t 8.1 (Berkeley) 6/5/93
.\"
-.ds RH Overview of the file system
+.ds RH Overview of the filesystem
.NH
-Overview of the file system
+Overview of the filesystem
.PP
-The file system is discussed in detail in [Mckusick84];
+The filesystem is discussed in detail in [Mckusick84];
this section gives a brief overview.
.NH 2
Superblock
.PP
-A file system is described by its
+A filesystem is described by its
.I "super-block" .
-The super-block is built when the file system is created (\c
+The super-block is built when the filesystem is created (\c
.I newfs (8))
and never changes.
The super-block
-contains the basic parameters of the file system,
+contains the basic parameters of the filesystem,
such as the number of data blocks it contains
and a count of the maximum number of files.
Because the super-block contains critical data,
@@ -56,7 +56,7 @@ replicates it to protect against catastrophic loss.
The
.I "default super block"
always resides at a fixed offset from the beginning
-of the file system's disk partition.
+of the filesystem's disk partition.
The
.I "redundant super blocks"
are not referenced unless a head crash
@@ -64,7 +64,7 @@ or other hard disk error causes the default super-block
to be unusable.
The redundant blocks are sprinkled throughout the disk partition.
.PP
-Within the file system are files.
+Within the filesystem are files.
Certain files are distinguished as directories and contain collections
of pointers to files that may themselves be directories.
Every file has a descriptor associated with it called an
@@ -82,7 +82,7 @@ the range 5-13.
.FE
The inode structure may also contain references to indirect blocks
containing further data block indices.
-In a file system with a 4096 byte block size, a singly indirect
+In a filesystem with a 4096 byte block size, a singly indirect
block contains 1024 further block addresses,
a doubly indirect block contains 1024 addresses of further single indirect
blocks,
@@ -92,30 +92,30 @@ blocks (the triple indirect block is never needed in practice).
In order to create files with up to
2\(ua32 bytes,
using only two levels of indirection,
-the minimum size of a file system block is 4096 bytes.
-The size of file system blocks can be any power of two
+the minimum size of a filesystem block is 4096 bytes.
+The size of filesystem blocks can be any power of two
greater than or equal to 4096.
-The block size of the file system is maintained in the super-block,
-so it is possible for file systems of different block sizes
+The block size of the filesystem is maintained in the super-block,
+so it is possible for filesystems of different block sizes
to be accessible simultaneously on the same system.
The block size must be decided when
.I newfs
-creates the file system;
+creates the filesystem;
the block size cannot be subsequently
-changed without rebuilding the file system.
+changed without rebuilding the filesystem.
.NH 2
Summary information
.PP
Associated with the super block is non replicated
.I "summary information" .
The summary information changes
-as the file system is modified.
+as the filesystem is modified.
The summary information contains
-the number of blocks, fragments, inodes and directories in the file system.
+the number of blocks, fragments, inodes and directories in the filesystem.
.NH 2
Cylinder groups
.PP
-The file system partitions the disk into one or more areas called
+The filesystem partitions the disk into one or more areas called
.I "cylinder groups".
A cylinder group is comprised of one or more consecutive
cylinders on a disk.
@@ -125,7 +125,7 @@ describing available blocks in the cylinder group,
and summary information describing the usage of data blocks
within the cylinder group.
A fixed number of inodes is allocated for each cylinder group
-when the file system is created.
+when the filesystem is created.
The current policy is to allocate one inode for each 2048
bytes of disk space;
this is expected to be far more inodes than will ever be needed.
@@ -158,12 +158,12 @@ and the beginning of the cylinder group information stores data.
Fragments
.PP
To avoid waste in storing small files,
-the file system space allocator divides a single
-file system block into one or more
+the filesystem space allocator divides a single
+filesystem block into one or more
.I "fragments".
-The fragmentation of the file system is specified
-when the file system is created;
-each file system block can be optionally broken into
+The fragmentation of the filesystem is specified
+when the filesystem is created;
+each filesystem block can be optionally broken into
2, 4, or 8 addressable fragments.
The lower bound on the size of these fragments is constrained
by the disk sector size;
@@ -173,17 +173,17 @@ records the space availability at the fragment level.
Aligned fragments are examined
to determine block availability.
.PP
-On a file system with a block size of 4096 bytes
+On a filesystem with a block size of 4096 bytes
and a fragment size of 1024 bytes,
a file is represented by zero or more 4096 byte blocks of data,
and possibly a single fragmented block.
-If a file system block must be fragmented to obtain
+If a filesystem block must be fragmented to obtain
space for a small amount of data,
the remainder of the block is made available for allocation
to other files.
For example,
consider an 11000 byte file stored on
-a 4096/1024 byte file system.
+a 4096/1024 byte filesystem.
This file uses two full size blocks and a 3072 byte fragment.
If no fragments with at least 3072 bytes
are available when the file is created,
@@ -191,26 +191,26 @@ a full size block is split yielding the necessary 3072 byte
fragment and an unused 1024 byte fragment.
This remaining fragment can be allocated to another file, as needed.
.NH 2
-Updates to the file system
+Updates to the filesystem
.PP
Every working day hundreds of files
are created, modified, and removed.
Every time a file is modified,
the operating system performs a
-series of file system updates.
-These updates, when written on disk, yield a consistent file system.
-The file system stages
+series of filesystem updates.
+These updates, when written on disk, yield a consistent filesystem.
+The filesystem stages
all modifications of critical information;
modification can
either be completed or cleanly backed out after a crash.
-Knowing the information that is first written to the file system,
+Knowing the information that is first written to the filesystem,
deterministic procedures can be developed to
-repair a corrupted file system.
+repair a corrupted filesystem.
To understand this process,
the order that the update
requests were being honored must first be understood.
.PP
-When a user program does an operation to change the file system,
+When a user program does an operation to change the filesystem,
such as a
.I write ,
the data to be written is copied into an internal
@@ -225,9 +225,9 @@ is eventually written out to disk.
The real disk write may not happen until long after the
.I write
system call has returned.
-Thus at any given time, the file system,
+Thus at any given time, the filesystem,
as it resides on the disk,
-lags the state of the file system represented by the in-core information.
+lags the state of the filesystem represented by the in-core information.
.PP
The disk information is updated to reflect the in-core information
when the buffer is required for another use,
@@ -239,7 +239,7 @@ or by manual operator intervention with the
.I sync (8)
command.
If the system is halted without writing out the in-core information,
-the file system on the disk will be in an inconsistent state.
+the filesystem on the disk will be in an inconsistent state.
.PP
If all updates are done asynchronously, several serious
inconsistencies can arise.
@@ -263,4 +263,4 @@ really written to disk)
when they are being deallocated.
Similarly inodes are kept consistent by synchronously
deleting, adding, or changing directory entries.
-.ds RH Fixing corrupted file systems
+.ds RH Fixing corrupted filesystems
diff --git a/sbin/fsck_ffs/SMM.doc/3.t b/sbin/fsck_ffs/SMM.doc/3.t
index 66c3281..b02371b 100644
--- a/sbin/fsck_ffs/SMM.doc/3.t
+++ b/sbin/fsck_ffs/SMM.doc/3.t
@@ -32,11 +32,11 @@
.\" $FreeBSD$
.\" @(#)3.t 8.1 (Berkeley) 6/5/93
.\"
-.ds RH Fixing corrupted file systems
+.ds RH Fixing corrupted filesystems
.NH
-Fixing corrupted file systems
+Fixing corrupted filesystems
.PP
-A file system
+A filesystem
can become corrupted in several ways.
The most common of these ways are
improper shutdown procedures
@@ -46,17 +46,17 @@ File systems may become corrupted during an
.I "unclean halt" .
This happens when proper shutdown
procedures are not observed,
-physically write-protecting a mounted file system,
-or a mounted file system is taken off-line.
+physically write-protecting a mounted filesystem,
+or a mounted filesystem is taken off-line.
The most common operator procedural failure is forgetting to
.I sync
the system before halting the CPU.
.PP
File systems may become further corrupted if proper startup
procedures are not observed, e.g.,
-not checking a file system for inconsistencies,
+not checking a filesystem for inconsistencies,
and not repairing inconsistencies.
-Allowing a corrupted file system to be used (and, thus, to be modified
+Allowing a corrupted filesystem to be used (and, thus, to be modified
further) can be disastrous.
.PP
Any piece of hardware can fail at any time.
@@ -87,13 +87,13 @@ A quiescent\(dd
.FS
\(dd I.e., unmounted and not being written on.
.FE
-file system may be checked for structural integrity
+filesystem may be checked for structural integrity
by performing consistency checks on the
-redundant data intrinsic to a file system.
+redundant data intrinsic to a filesystem.
The redundant data is either read from
-the file system,
+the filesystem,
or computed from other known values.
-The file system
+The filesystem
.B must
be in a quiescent state when
.I fsck_ffs
@@ -110,7 +110,7 @@ the data blocks containing directory entries.
.NH 2
Super-block checking
.PP
-The most commonly corrupted item in a file system
+The most commonly corrupted item in a filesystem
is the summary information
associated with the super-block.
The summary information is prone to corruption
@@ -133,7 +133,7 @@ since they are statically determined by
.I newfs ,
.I fsck_ffs
can check that these sizes are within reasonable bounds.
-All other file system checks require that these sizes be correct.
+All other filesystem checks require that these sizes be correct.
If
.I fsck_ffs
detects corruption in the static parameters of the default super-block,
@@ -151,7 +151,7 @@ When all the blocks have been initially accounted for,
checks that
the number of free blocks
plus the number of blocks claimed by the inodes
-equals the total number of blocks in the file system.
+equals the total number of blocks in the filesystem.
.PP
If anything is wrong with the block allocation maps,
.I fsck_ffs
@@ -159,20 +159,20 @@ will rebuild them,
based on the list it has computed of allocated blocks.
.PP
The summary information associated with the super-block
-counts the total number of free blocks within the file system.
+counts the total number of free blocks within the filesystem.
.I Fsck_ffs
compares this count to the
-number of free blocks it found within the file system.
+number of free blocks it found within the filesystem.
If the two counts do not agree, then
.I fsck_ffs
replaces the incorrect count in the summary information
by the actual free-block count.
.PP
The summary information
-counts the total number of free inodes within the file system.
+counts the total number of free inodes within the filesystem.
.I Fsck_ffs
compares this count to the number
-of free inodes it found within the file system.
+of free inodes it found within the filesystem.
If the two counts do not agree, then
.I fsck_ffs
replaces the incorrect count in the
@@ -185,11 +185,11 @@ the allocation information.
However, because of the great number of active inodes,
a few of the inodes are usually corrupted.
.PP
-The list of inodes in the file system
+The list of inodes in the filesystem
is checked sequentially starting with inode 2
(inode 0 marks unused inodes;
inode 1 is saved for future generations)
-and progressing through the last inode in the file system.
+and progressing through the last inode in the filesystem.
The state of each inode is checked for
inconsistencies involving format and type,
link count,
@@ -218,7 +218,7 @@ total number of directory entries
linked to the inode.
.I Fsck_ffs
verifies the link count of each inode
-by starting at the root of the file system,
+by starting at the root of the filesystem,
and descending through the directory structure.
The actual link count for each inode
is calculated during the descent.
@@ -279,12 +279,12 @@ and which one should be cleared.
.I Fsck_ffs
checks the range of each block number claimed by an inode.
If the block number is
-lower than the first data block in the file system,
+lower than the first data block in the filesystem,
or greater than the last data block,
then the block number is a
.I "bad block number" .
Many bad blocks in an inode are usually caused by
-an indirect block that was not written to the file system,
+an indirect block that was not written to the filesystem,
a condition which can only occur if there has been a hardware failure.
If an inode contains bad block numbers,
.I fsck_ffs
@@ -334,9 +334,9 @@ several types of inconsistencies.
These inconsistencies include
directory inode numbers pointing to unallocated inodes,
directory inode numbers that are greater than
-the number of inodes in the file system,
+the number of inodes in the filesystem,
incorrect directory inode numbers for ``\fB.\fP'' and ``\fB..\fP'',
-and directories that are not attached to the file system.
+and directories that are not attached to the filesystem.
If the inode number in a directory data block
references an unallocated inode,
then
@@ -390,10 +390,10 @@ to which ``\fB..\fP'' should point;
File system connectivity
.PP
.I Fsck_ffs
-checks the general connectivity of the file system.
-If directories are not linked into the file system, then
+checks the general connectivity of the filesystem.
+If directories are not linked into the filesystem, then
.I fsck_ffs
-links the directory back into the file system in the
+links the directory back into the filesystem in the
.I lost+found
directory.
This condition only occurs when there has been a hardware failure.
@@ -402,7 +402,7 @@ This condition only occurs when there has been a hardware failure.
\s+2Acknowledgements\s0
.PP
I thank Bill Joy, Sam Leffler, Robert Elz and Dennis Ritchie
-for their suggestions and help in implementing the new file system.
+for their suggestions and help in implementing the new filesystem.
Thanks also to Robert Henry for his editorial input to
get this document together.
Finally we thank our sponsors,
diff --git a/sbin/fsck_ffs/SMM.doc/4.t b/sbin/fsck_ffs/SMM.doc/4.t
index 5c23dcc..7f52588 100644
--- a/sbin/fsck_ffs/SMM.doc/4.t
+++ b/sbin/fsck_ffs/SMM.doc/4.t
@@ -40,13 +40,13 @@ Conventions
.PP
.I Fsck_ffs
is
-a multi-pass file system check program.
-Each file system pass invokes a different Phase of the
+a multi-pass filesystem check program.
+Each filesystem pass invokes a different Phase of the
.I fsck_ffs
program.
After the initial setup,
.I fsck_ffs
-performs successive Phases over each file system,
+performs successive Phases over each filesystem,
checking blocks and sizes,
path-names,
connectivity,
@@ -59,8 +59,8 @@ Normally
.I fsck_ffs
is run non-interactively to
.I preen
-the file systems after an unclean halt.
-While preen'ing a file system,
+the filesystems after an unclean halt.
+While preen'ing a filesystem,
it will only fix corruptions that are expected
to occur from an unclean halt.
These actions are a proper subset of the actions that
@@ -92,7 +92,7 @@ will be discussed in initialization.
.NH 2
Initialization
.PP
-Before a file system check can be performed, certain
+Before a filesystem check can be performed, certain
tables have to be set up and certain files opened.
This section concerns itself with the opening of files and
the initialization of tables.
@@ -101,10 +101,10 @@ command line options,
memory requests,
opening of files,
status of files,
-file system size checks,
+filesystem size checks,
and creation of the scratch file.
All the initialization errors are fatal
-when the file system is being preen'ed.
+when the filesystem is being preen'ed.
.sp
.LP
.B "\fIC\fP option?"
@@ -138,7 +138,7 @@ See a guru.
.LP
.B "Can't open checklist file: \fIF\fP"
.br
-The file system checklist file
+The filesystem checklist file
\fIF\fP (usually
.I /etc/fstab )
can not be opened for reading.
@@ -162,19 +162,19 @@ See a guru.
.B "Can't make sense out of name \fIF\fP"
.br
.I Fsck_ffs 's
-request for statistics about the file system \fIF\fP failed.
+request for statistics about the filesystem \fIF\fP failed.
When running manually,
-it ignores this file system
-and continues checking the next file system given.
+it ignores this filesystem
+and continues checking the next filesystem given.
Check access modes of \fIF\fP.
.sp
.LP
.B "Can't open \fIF\fP"
.br
.I Fsck_ffs 's
-request attempt to open the file system \fIF\fP failed.
-When running manually, it ignores this file system
-and continues checking the next file system given.
+request attempt to open the filesystem \fIF\fP failed.
+When running manually, it ignores this filesystem
+and continues checking the next filesystem given.
Check access modes of \fIF\fP.
.sp
.LP
@@ -182,7 +182,7 @@ Check access modes of \fIF\fP.
.br
Either the \-n flag was specified or
.I fsck_ffs 's
-attempt to open the file system \fIF\fP for writing failed.
+attempt to open the filesystem \fIF\fP for writing failed.
When running manually,
all the diagnostics are printed out,
but no modifications are attempted to fix them.
@@ -199,8 +199,8 @@ Possible responses to the OK prompt are:
.IP YES
ignore this error condition.
.IP NO
-ignore this file system and continues checking
-the next file system given.
+ignore this filesystem and continues checking
+the next filesystem given.
.sp
.LP
.B "UNDEFINED OPTIMIZATION IN SUPERBLOCK (SET TO DEFAULT)"
@@ -234,7 +234,7 @@ ignore this error condition.
.LP
.B "IMPOSSIBLE INTERLEAVE=\fID\fP IN SUPERBLOCK (SET TO DEFAULT)"
.br
-The file system interleave is less than or equal to zero.
+The filesystem interleave is less than or equal to zero.
.LP
Possible responses to the SET TO DEFAULT prompt are:
.IP YES
@@ -281,8 +281,8 @@ The super block has been corrupted.
An alternative super block must be selected from among those
listed by
.I newfs
-(8) when the file system was created.
-For file systems with a blocksize less than 32K,
+(8) when the filesystem was created.
+For filesystems with a blocksize less than 32K,
specifying \-b 32 is a good first choice.
.sp
.LP
@@ -298,19 +298,19 @@ See a guru.
.br
.I Fsck_ffs 's
request for moving to a specified block number \fIB\fP in
-the file system failed.
+the filesystem failed.
This should never happen.
See a guru.
.LP
Possible responses to the CONTINUE prompt are:
.IP YES
-attempt to continue to run the file system check.
+attempt to continue to run the filesystem check.
Often,
however the problem will persist.
-This error condition will not allow a complete check of the file system.
+This error condition will not allow a complete check of the filesystem.
A second run of
.I fsck_ffs
-should be made to re-check this file system.
+should be made to re-check this filesystem.
If the block was part of the virtual memory buffer
cache,
.I fsck_ffs
@@ -323,13 +323,13 @@ terminate the program.
.br
.I Fsck_ffs 's
request for reading a specified block number \fIB\fP in
-the file system failed.
+the filesystem failed.
This should never happen.
See a guru.
.LP
Possible responses to the CONTINUE prompt are:
.IP YES
-attempt to continue to run the file system check.
+attempt to continue to run the filesystem check.
It will retry the read and print out the message:
.br
.B "THE FOLLOWING SECTORS COULD NOT BE READ: \fIN\fP"
@@ -344,10 +344,10 @@ it will print the message:
.br
where \fIN\fP indicates the sector that was written with zero's.
If the disk is experiencing hardware problems, the problem will persist.
-This error condition will not allow a complete check of the file system.
+This error condition will not allow a complete check of the filesystem.
A second run of
.I fsck_ffs
-should be made to re-check this file system.
+should be made to re-check this filesystem.
If the block was part of the virtual memory buffer
cache,
.I fsck_ffs
@@ -360,14 +360,14 @@ terminate the program.
.br
.I Fsck_ffs 's
request for writing a specified block number \fIB\fP
-in the file system failed.
+in the filesystem failed.
The disk is write-protected;
check the write protect lock on the drive.
If that is not the problem, see a guru.
.LP
Possible responses to the CONTINUE prompt are:
.IP YES
-attempt to continue to run the file system check.
+attempt to continue to run the filesystem check.
The write operation will be retried with the failed blocks
indicated by the message:
.br
@@ -375,10 +375,10 @@ indicated by the message:
.br
where \fIN\fP indicates the sectors that could not be written.
If the disk is experiencing hardware problems, the problem will persist.
-This error condition will not allow a complete check of the file system.
+This error condition will not allow a complete check of the filesystem.
A second run of
.I fsck_ffs
-should be made to re-check this file system.
+should be made to re-check this filesystem.
If the block was part of the virtual memory buffer
cache,
.I fsck_ffs
@@ -409,7 +409,7 @@ All errors in this phase except
.B "INCORRECT BLOCK COUNT"
and
.B "PARTIALLY TRUNCATED INODE"
-are fatal if the file system is being preen'ed.
+are fatal if the filesystem is being preen'ed.
.sp
.LP
.B "UNKNOWN FILE TYPE I=\fII\fP (CLEAR)"
@@ -434,7 +434,7 @@ has found inode \fII\fP whose size is shorter than the number of
blocks allocated to it.
This condition should only occur if the system crashes while in the
midst of truncating a file.
-When preen'ing the file system,
+When preen'ing the filesystem,
.I fsck_ffs
completes the truncation to the specified size.
.LP
@@ -457,10 +457,10 @@ Increase the virtual memory for
Possible responses to the CONTINUE prompt are:
.IP YES
continue with the program.
-This error condition will not allow a complete check of the file system.
+This error condition will not allow a complete check of the filesystem.
A second run of
.I fsck_ffs
-should be made to re-check this file system.
+should be made to re-check this filesystem.
If another allocated inode with a zero link count is found,
this error condition is repeated.
.IP NO
@@ -470,13 +470,13 @@ terminate the program.
.B "\fIB\fP BAD I=\fII\fP"
.br
Inode \fII\fP contains block number \fIB\fP with a number
-lower than the number of the first data block in the file system or
+lower than the number of the first data block in the filesystem or
greater than the number of the last block
-in the file system.
+in the filesystem.
This error condition may invoke the
.B "EXCESSIVE BAD BLKS"
error condition in Phase 1 (see next paragraph) if
-inode \fII\fP has too many block numbers outside the file system range.
+inode \fII\fP has too many block numbers outside the filesystem range.
This error condition will always invoke the
.B "BAD/DUP"
error condition in Phase 2 and Phase 4.
@@ -485,17 +485,17 @@ error condition in Phase 2 and Phase 4.
.B "EXCESSIVE BAD BLKS I=\fII\fP (CONTINUE)"
.br
There is more than a tolerable number (usually 10) of blocks with a number
-lower than the number of the first data block in the file system or greater than
-the number of last block in the file system associated with inode \fII\fP.
+lower than the number of the first data block in the filesystem or greater than
+the number of last block in the filesystem associated with inode \fII\fP.
.LP
Possible responses to the CONTINUE prompt are:
.IP YES
ignore the rest of the blocks in this inode
-and continue checking with the next inode in the file system.
-This error condition will not allow a complete check of the file system.
+and continue checking with the next inode in the filesystem.
+This error condition will not allow a complete check of the filesystem.
A second run of
.I fsck_ffs
-should be made to re-check this file system.
+should be made to re-check this filesystem.
.IP NO
terminate the program.
.sp
@@ -531,11 +531,11 @@ inodes.
Possible responses to the CONTINUE prompt are:
.IP YES
ignore the rest of the blocks in this inode
-and continue checking with the next inode in the file system.
-This error condition will not allow a complete check of the file system.
+and continue checking with the next inode in the filesystem.
+This error condition will not allow a complete check of the filesystem.
A second run of
.I fsck_ffs
-should be made to re-check this file system.
+should be made to re-check this filesystem.
.IP NO
terminate the program.
.sp
@@ -551,10 +551,10 @@ Increase the amount of virtual memory available to
Possible responses to the CONTINUE prompt are:
.IP YES
continue with the program.
-This error condition will not allow a complete check of the file system.
+This error condition will not allow a complete check of the filesystem.
A second run of
.I fsck_ffs
-should be made to re-check this file system.
+should be made to re-check this filesystem.
If another duplicate block is found, this error condition will repeat.
.IP NO
terminate the program.
@@ -585,7 +585,7 @@ ignore this error condition.
.NH 2
Phase 1B: Rescan for More Dups
.PP
-When a duplicate block is found in the file system, the file system is
+When a duplicate block is found in the filesystem, the filesystem is
rescanned to find the inode that previously claimed that block.
This section lists the error condition when the duplicate block is found.
.sp
@@ -611,7 +611,7 @@ root inode mode and status,
directory inode pointers in range,
and directory entries pointing to bad inodes,
and directory integrity checks.
-All errors in this phase are fatal if the file system is being preen'ed,
+All errors in this phase are fatal if the filesystem is being preen'ed,
except for directories not being a multiple of the blocks size
and extraneous hard links.
.sp
@@ -671,7 +671,7 @@ terminate the program.
.B "DUPS/BAD IN ROOT INODE (REALLOCATE)"
.br
Phase 1 or Phase 1b have found duplicate blocks
-or bad blocks in the root inode (usually inode number 2) for the file system.
+or bad blocks in the root inode (usually inode number 2) for the filesystem.
.LP
Possible responses to the REALLOCATE prompt are:
.IP YES
@@ -695,7 +695,7 @@ Possible responses to the CONTINUE prompt are:
ignore the
.B "DUPS/BAD"
error condition in the root inode and
-attempt to continue to run the file system check.
+attempt to continue to run the filesystem check.
If the root inode is not correct,
then this may result in many other error conditions.
.IP NO
@@ -705,7 +705,7 @@ terminate the program.
.B "NAME TOO LONG \fIF\fP"
.br
An excessively long path name has been found.
-This usually indicates loops in the file system name space.
+This usually indicates loops in the filesystem name space.
This can occur if the super user has made circular links to directories.
The offending links must be removed (by a guru).
.sp
@@ -785,8 +785,8 @@ a multiple of the directory blocksize \fIB\fP.
Possible responses to the ADJUST prompt are:
.IP YES
the length is rounded up to the appropriate block size.
-This error can occur on 4.2BSD file systems.
-Thus when preen'ing the file system only a warning is printed
+This error can occur on 4.2BSD filesystems.
+Thus when preen'ing the filesystem only a warning is printed
and the directory is adjusted.
.IP NO
ignore the error condition.
@@ -837,9 +837,9 @@ leave the directory unchanged.
A directory \fII\fP has been found whose first entry is \fIF\fP.
.I Fsck_ffs
cannot resolve this problem.
-The file system should be mounted and the offending entry \fIF\fP
+The filesystem should be mounted and the offending entry \fIF\fP
moved elsewhere.
-The file system should then be unmounted and
+The filesystem should then be unmounted and
.I fsck_ffs
should be run again.
.sp
@@ -897,9 +897,9 @@ leave the directory unchanged.
A directory \fII\fP has been found whose second entry is \fIF\fP.
.I Fsck_ffs
cannot resolve this problem.
-The file system should be mounted and the offending entry \fIF\fP
+The filesystem should be mounted and the offending entry \fIF\fP
moved elsewhere.
-The file system should then be unmounted and
+The filesystem should then be unmounted and
.I fsck_ffs
should be run again.
.sp
@@ -911,9 +911,9 @@ should be run again.
A directory \fII\fP has been found whose second entry is not `..'.
.I Fsck_ffs
cannot resolve this problem.
-The file system should be mounted and the second entry in the directory
+The filesystem should be mounted and the second entry in the directory
moved elsewhere.
-The file system should then be unmounted and
+The filesystem should then be unmounted and
.I fsck_ffs
should be run again.
.sp
@@ -945,7 +945,7 @@ ignore the error condition.
.B "BAD INODE \fIS\fP TO DESCEND"
.br
An internal error has caused an impossible state \fIS\fP to be passed to the
-routine that descends the file system directory structure.
+routine that descends the filesystem directory structure.
.I Fsck_ffs
exits.
See a guru.
@@ -954,7 +954,7 @@ See a guru.
.B "BAD RETURN STATE \fIS\fP FROM DESCEND"
.br
An internal error has caused an impossible state \fIS\fP to be returned
-from the routine that descends the file system directory structure.
+from the routine that descends the filesystem directory structure.
.I Fsck_ffs
exits.
See a guru.
@@ -982,7 +982,7 @@ directories.
.B "UNREF DIR I=\fII\fP OWNER=\fIO\fP MODE=\fIM\fP SIZE=\fIS\fP MTIME=\fIT\fP (RECONNECT)"
.br
The directory inode \fII\fP was not connected to a directory entry
-when the file system was traversed.
+when the filesystem was traversed.
The owner \fIO\fP, mode \fIM\fP, size \fIS\fP, and
modify time \fIT\fP of directory inode \fII\fP are printed.
When preen'ing, the directory is reconnected if its size is non-zero,
@@ -990,7 +990,7 @@ otherwise it is cleared.
.LP
Possible responses to the RECONNECT prompt are:
.IP YES
-reconnect directory inode \fII\fP to the file system in the
+reconnect directory inode \fII\fP to the filesystem in the
directory for lost files (usually \fIlost+found\fP).
This may invoke the
.I lost+found
@@ -1007,14 +1007,14 @@ This will always invoke the UNREF error condition in Phase 4.
.br
There is no
.I lost+found
-directory in the root directory of the file system;
+directory in the root directory of the filesystem;
When preen'ing
.I fsck_ffs
tries to create a \fIlost+found\fP directory.
.LP
Possible responses to the CREATE prompt are:
.IP YES
-create a \fIlost+found\fP directory in the root of the file system.
+create a \fIlost+found\fP directory in the root of the filesystem.
This may raise the message:
.br
.B "NO SPACE LEFT IN / (EXPAND)"
@@ -1059,7 +1059,7 @@ This will always invoke the UNREF error condition in Phase 4.
There is no space to add another entry to the
.I lost+found
directory in the root directory
-of the file system.
+of the filesystem.
When preen'ing the
.I lost+found
directory is expanded.
@@ -1079,7 +1079,7 @@ and aborts the attempt to linkup the lost inode.
This will always invoke the UNREF error condition in Phase 4.
Clean out unnecessary entries in
.I lost+found .
-This error is fatal if the file system is being preen'ed.
+This error is fatal if the filesystem is being preen'ed.
.IP NO
abort the attempt to linkup the lost inode.
This will always invoke the UNREF error condition in Phase 4.
@@ -1106,8 +1106,8 @@ a multiple of the directory blocksize \fIB\fP
Possible responses to the ADJUST prompt are:
.IP YES
the length is rounded up to the appropriate block size.
-This error can occur on 4.2BSD file systems.
-Thus when preen'ing the file system only a warning is printed
+This error can occur on 4.2BSD filesystems.
+Thus when preen'ing the filesystem only a warning is printed
and the directory is adjusted.
.IP NO
ignore the error condition.
@@ -1116,7 +1116,7 @@ ignore the error condition.
.B "BAD INODE \fIS\fP TO DESCEND"
.br
An internal error has caused an impossible state \fIS\fP to be passed to the
-routine that descends the file system directory structure.
+routine that descends the filesystem directory structure.
.I Fsck_ffs
exits.
See a guru.
@@ -1133,14 +1133,14 @@ directory,
incorrect link counts for files, directories, symbolic links, or special files,
unreferenced files, symbolic links, and directories,
and bad or duplicate blocks in files, symbolic links, and directories.
-All errors in this phase are correctable if the file system is being preen'ed
+All errors in this phase are correctable if the filesystem is being preen'ed
except running out of space in the \fIlost+found\fP directory.
.sp
.LP
.B "UNREF FILE I=\fII\fP OWNER=\fIO\fP MODE=\fIM\fP SIZE=\fIS\fP MTIME=\fIT\fP (RECONNECT)"
.br
Inode \fII\fP was not connected to a directory entry
-when the file system was traversed.
+when the filesystem was traversed.
The owner \fIO\fP, mode \fIM\fP, size \fIS\fP, and
modify time \fIT\fP of inode \fII\fP are printed.
When preen'ing the file is cleared if either its size or its
@@ -1149,7 +1149,7 @@ otherwise it is reconnected.
.LP
Possible responses to the RECONNECT prompt are:
.IP YES
-reconnect inode \fII\fP to the file system in the directory for
+reconnect inode \fII\fP to the filesystem in the directory for
lost files (usually \fIlost+found\fP).
This may invoke the
.I lost+found
@@ -1165,7 +1165,7 @@ This will always invoke the CLEAR error condition in Phase 4.
.br
The inode mentioned in the immediately previous error condition can not be
reconnected.
-This cannot occur if the file system is being preen'ed,
+This cannot occur if the filesystem is being preen'ed,
since lack of space to reconnect files is a fatal error.
.LP
Possible responses to the CLEAR prompt are:
@@ -1179,14 +1179,14 @@ ignore this error condition.
.br
There is no
.I lost+found
-directory in the root directory of the file system;
+directory in the root directory of the filesystem;
When preen'ing
.I fsck_ffs
tries to create a \fIlost+found\fP directory.
.LP
Possible responses to the CREATE prompt are:
.IP YES
-create a \fIlost+found\fP directory in the root of the file system.
+create a \fIlost+found\fP directory in the root of the filesystem.
This may raise the message:
.br
.B "NO SPACE LEFT IN / (EXPAND)"
@@ -1231,7 +1231,7 @@ This will always invoke the UNREF error condition in Phase 4.
There is no space to add another entry to the
.I lost+found
directory in the root directory
-of the file system.
+of the filesystem.
When preen'ing the
.I lost+found
directory is expanded.
@@ -1251,7 +1251,7 @@ and aborts the attempt to linkup the lost inode.
This will always invoke the UNREF error condition in Phase 4.
Clean out unnecessary entries in
.I lost+found .
-This error is fatal if the file system is being preen'ed.
+This error is fatal if the filesystem is being preen'ed.
.IP NO
abort the attempt to linkup the lost inode.
This will always invoke the UNREF error condition in Phase 4.
@@ -1282,7 +1282,7 @@ ignore this error condition.
.B "UNREF \fItype\fP I=\fII\fP OWNER=\fIO\fP MODE=\fIM\fP SIZE=\fIS\fP MTIME=\fIT\fP (CLEAR)"
.br
Inode \fII\fP, was not connected to a directory entry when the
-file system was traversed.
+filesystem was traversed.
The owner \fIO\fP, mode \fIM\fP, size \fIS\fP,
and modify time \fIT\fP of inode \fII\fP
are printed.
@@ -1305,7 +1305,7 @@ inode \fII\fP.
The owner \fIO\fP, mode \fIM\fP, size \fIS\fP,
and modify time \fIT\fP of inode \fII\fP
are printed.
-This error cannot arise when the file system is being preen'ed,
+This error cannot arise when the filesystem is being preen'ed,
as it would have caused a fatal error earlier.
.LP
Possible responses to the CLEAR prompt are:
@@ -1333,7 +1333,7 @@ The magic number of cylinder group \fIC\fP is wrong.
This usually indicates that the cylinder group maps have been destroyed.
When running manually the cylinder group is marked as needing
to be reconstructed.
-This error is fatal if the file system is being preen'ed.
+This error is fatal if the filesystem is being preen'ed.
.sp
.LP
.B "BLK(S) MISSING IN BIT MAPS (SALVAGE)"
@@ -1375,19 +1375,19 @@ ignore this error condition.
.NH 2
Cleanup
.PP
-Once a file system has been checked, a few cleanup functions are performed.
+Once a filesystem has been checked, a few cleanup functions are performed.
This section lists advisory messages about
-the file system
-and modify status of the file system.
+the filesystem
+and modify status of the filesystem.
.sp
.LP
.B "\fIV\fP files, \fIW\fP used, \fIX\fP free (\fIY\fP frags, \fIZ\fP blocks)"
.br
This is an advisory message indicating that
-the file system checked contained
+the filesystem checked contained
\fIV\fP files using
\fIW\fP fragment sized blocks leaving
-\fIX\fP fragment sized blocks free in the file system.
+\fIX\fP fragment sized blocks free in the filesystem.
The numbers in parenthesis breaks the free count down into
\fIY\fP free fragments and
\fIZ\fP free full sized blocks.
@@ -1396,7 +1396,7 @@ The numbers in parenthesis breaks the free count down into
.B "***** REBOOT UNIX *****"
.br
This is an advisory message indicating that
-the root file system has been modified by
+the root filesystem has been modified by
.I fsck_ffs.
If UNIX is not rebooted immediately,
the work done by
@@ -1413,9 +1413,9 @@ interprets an exit code of 4 by issuing a reboot system call.
.B "***** FILE SYSTEM WAS MODIFIED *****"
.br
This is an advisory message indicating that
-the current file system was modified by
+the current filesystem was modified by
.I fsck_ffs.
-If this file system is mounted or is the current root file system,
+If this filesystem is mounted or is the current root filesystem,
.I fsck_ffs
should be halted and UNIX rebooted.
If UNIX is not rebooted immediately,
diff --git a/sbin/fsck_ffs/main.c b/sbin/fsck_ffs/main.c
index eaf90dd..73364a7 100644
--- a/sbin/fsck_ffs/main.c
+++ b/sbin/fsck_ffs/main.c
@@ -308,7 +308,7 @@ checkfilesys(char *filesys)
if (preen == 0) {
printf("** Last Mounted on %s\n", sblock.fs_fsmnt);
if (mntp != NULL && mntp->f_flags & MNT_ROOTFS)
- printf("** Root file system\n");
+ printf("** Root filesystem\n");
printf("** Phase 1 - Check Blocks and Sizes\n");
}
pass1();
diff --git a/sbin/fsck_ffs/pass1.c b/sbin/fsck_ffs/pass1.c
index ef31787..cfb8af8 100644
--- a/sbin/fsck_ffs/pass1.c
+++ b/sbin/fsck_ffs/pass1.c
@@ -68,7 +68,7 @@ pass1(void)
struct inodesc idesc;
/*
- * Set file system reserved blocks in used block map.
+ * Set filesystem reserved blocks in used block map.
*/
for (c = 0; c < sblock.fs_ncg; c++) {
cgd = cgdmin(&sblock, c);
OpenPOWER on IntegriCloud
diff --git a/sbin/fsck_ffs/fsck.h b/sbin/fsck_ffs/fsck.h
index e94a6b7..2df0cd8 100644
--- a/sbin/fsck_ffs/fsck.h
+++ b/sbin/fsck_ffs/fsck.h
@@ -97,7 +97,7 @@ struct bufarea {
#define MINBUFS 5 /* minimum number of buffers required */
struct bufarea bufhead; /* head of list of other blks in filesys */
-struct bufarea sblk; /* file system superblock */
+struct bufarea sblk; /* filesystem superblock */
struct bufarea cgblk; /* cylinder group blocks */
struct bufarea *pdirbp; /* current directory contents */
struct bufarea *pbp; /* current inode block */
@@ -210,7 +210,7 @@ char yflag; /* assume a yes response */
int bkgrdflag; /* use a snapshot to run on an active system */
int bflag; /* location of alternate super block */
int debug; /* output debugging info */
-int cvtlevel; /* convert to newer file system format */
+int cvtlevel; /* convert to newer filesystem format */
int bkgrdcheck; /* determine if background check is possible */
char usedsoftdep; /* just fix soft dependency inconsistencies */
char preen; /* just fix normal inconsistencies */
@@ -218,14 +218,14 @@ char rerun; /* rerun fsck. Only used in non-preen mode */
int returntosingle; /* 1 => return to single user mode on exit */
char resolved; /* cleared if unresolved changes => not clean */
char havesb; /* superblock has been read */
-char skipclean; /* skip clean file systems if preening */
-int fsmodified; /* 1 => write done to file system */
-int fsreadfd; /* file descriptor for reading file system */
-int fswritefd; /* file descriptor for writing file system */
+char skipclean; /* skip clean filesystems if preening */
+int fsmodified; /* 1 => write done to filesystem */
+int fsreadfd; /* file descriptor for reading filesystem */
+int fswritefd; /* file descriptor for writing filesystem */
-ufs_daddr_t maxfsblock; /* number of blocks in the file system */
+ufs_daddr_t maxfsblock; /* number of blocks in the filesystem */
char *blockmap; /* ptr to primary blk allocation map */
-ino_t maxino; /* number of inodes in file system */
+ino_t maxino; /* number of inodes in filesystem */
ino_t lfdir; /* lost & found directory inode number */
char *lfname; /* lost & found directory name */